@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher::AO3;
-$WWW::FetchStory::Fetcher::AO3::VERSION = '0.1825';
+$WWW::FetchStory::Fetcher::AO3::VERSION = '0.1826';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher::AO3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1825
+version 0.1826
 
 =head1 DESCRIPTION
 
@@ -141,7 +141,7 @@ sub parse_toc {
     $info{category} = $self->parse_category(%args);
     $info{rating} = $self->parse_rating(%args);
     $info{chapters} = $self->parse_chapter_urls(%args, sid=>$sid);
-    $info{epub_url} = $self->parse_epub_url(%args, sid=>$sid);
+    #$info{epub_url} = $self->parse_epub_url(%args, sid=>$sid);
     $info{wordcount} = $self->parse_wordcount(%args);
 
     return %info;
@@ -167,7 +167,7 @@ sub parse_chapter_urls {
 	@chapters = @{$args{urls}};
     }
     if (@chapters == 1
-	    and $content =~ m!href="(/downloads/[-\/\w]+/$sid/[^.]+\.html)"!)
+	    and $content =~ m!href="(/downloads/[-\/\w]+/$sid/[^.]+\.html)!)
     {
 	@chapters = ("http://archiveofourown.org$1");
     }
@@ -190,7 +190,7 @@ sub parse_epub_url {
     my $content = $args{content};
     my $sid = $args{sid};
     my $epub_url = '';
-    if ($content =~ m!href="(/downloads/[-\/\w]+/$sid/[^.]+\.epub)"!)
+    if ($content =~ m!href="(/downloads/[-\/\w]+/$sid/[^.]+\.epub)!)
     {
 	$epub_url = ("http://archiveofourown.org$1");
     }
