@@ -1,5 +1,5 @@
 package WWW::FetchStory::Fetcher::FanfictionNet;
-$WWW::FetchStory::Fetcher::FanfictionNet::VERSION = '0.1825';
+$WWW::FetchStory::Fetcher::FanfictionNet::VERSION = '0.1826';
 use strict;
 use warnings;
 =head1 NAME
@@ -8,7 +8,7 @@ WWW::FetchStory::Fetcher::FanfictionNet - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1825
+version 0.1826
 
 =head1 DESCRIPTION
 
@@ -164,7 +164,7 @@ sub extract_story {
     if ($story)
     {
 	$out .= "<h1>$story_title</h1>\n";
-	$out .= "<p>by $author</p>\n";
+	$out .= "<p>by $author</p>\n" if $author;
 	$out .= "<br/>\n<b>Universe:</b> $universe\n" if $universe;
 	$out .= "<div>\n";
 	$out .= "$story\n";
